==> haskell-binary-instances-1.0.4-134-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-instances
version:              1.0.4
visibility:           public
id:                   binary-instances-1.0.4-HfOc7CcxwPK4Aqvob3o6qo
key:                  binary-instances-1.0.4-HfOc7CcxwPK4Aqvob3o6qo
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskellari/binary-instances#readme
synopsis:             Orphan instances for binary
description:
    `binary-instances` defines orphan instances for types in some popular packages.

category:             Web
abi:                  5a939332832b727ab1e8ad08e54f92fa
exposed:              True
exposed-modules:
    Data.Binary.Instances Data.Binary.Instances.Aeson
    Data.Binary.Instances.CaseInsensitive
    Data.Binary.Instances.Hashable Data.Binary.Instances.Primitive
    Data.Binary.Instances.Scientific Data.Binary.Instances.Tagged
    Data.Binary.Instances.Text Data.Binary.Instances.Time
    Data.Binary.Instances.UnorderedContainers
    Data.Binary.Instances.Vector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-instances-1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-instances-1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-instances-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-instances
hs-libraries:         HSbinary-instances-1.0.4-HfOc7CcxwPK4Aqvob3o6qo
depends:
    aeson-2.1.2.1-4RB85zdNr5p3whZ1np3a31 base-4.17.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-9p37NV8Cw2TK807j2vG9vE
    case-insensitive-1.2.1.0-LYFsGNYxHzcJNUKypl8Xr7
    hashable-1.4.5.0-EMf4Iv4OllUGRj72K4SCf0
    primitive-0.9.1.0-6nUciex1vJZHfhyE758nym
    scientific-0.3.8.0-75VbuY3tmfA8QFAgCCeEHk
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    text-binary-0.2.1.1-2Sbl9JTNRDTGn32vfvCeKg
    time-compat-1.9.7-2W3wF1ggYXz4QsPMsZxlo5
    unordered-containers-0.2.20-L410VxfvorQ5RMb8wocThG
    vector-0.13.2.0-B3Rnif6nhJNLHPAZlzHp2g
    vector-binary-instances-0.2.5.2-GpP6rhuvA8n580dfqJljYg

haddock-interfaces:
    /usr/share/doc/haskell-binary-instances/html/binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-binary-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-instances-1.0.4-135-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-instances
version:              1.0.4
visibility:           public
id:                   binary-instances-1.0.4-KObuTixpKf7Bq8Bb49878i
key:                  binary-instances-1.0.4-KObuTixpKf7Bq8Bb49878i
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskellari/binary-instances#readme
synopsis:             Orphan instances for binary
description:
    `binary-instances` defines orphan instances for types in some popular packages.

category:             Web
abi:                  74b85b8f034cb27a69f8be852091332d
exposed:              True
exposed-modules:
    Data.Binary.Instances Data.Binary.Instances.Aeson
    Data.Binary.Instances.CaseInsensitive
    Data.Binary.Instances.Hashable Data.Binary.Instances.Primitive
    Data.Binary.Instances.Scientific Data.Binary.Instances.Tagged
    Data.Binary.Instances.Text Data.Binary.Instances.Time
    Data.Binary.Instances.UnorderedContainers
    Data.Binary.Instances.Vector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-instances-1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-instances-1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-instances-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-instances
hs-libraries:         HSbinary-instances-1.0.4-KObuTixpKf7Bq8Bb49878i
depends:
    aeson-2.1.2.1-CoFGCad0PesDH4XC5ctCv4 base-4.17.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-GcSfBfaOQGA8w0krTDEUdD
    case-insensitive-1.2.1.0-761P1jvxXU26pNc4Eb30SJ
    hashable-1.4.5.0-46ofdJt9DgFJv5hpm4ccL9
    primitive-0.9.1.0-D2h8cSAG2AjKP2pRuhtPBO
    scientific-0.3.8.0-3ah0qUGLDw61YSMhCVhWLa
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    text-binary-0.2.1.1-2Sbl9JTNRDTGn32vfvCeKg
    time-compat-1.9.7-uuCCjWxpPz6K3a4xTVA7X
    unordered-containers-0.2.20-9wNMaDmysQKAAHkxxaXhUB
    vector-0.13.2.0-7UWGIXxclbLLOjGg0s2qXt
    vector-binary-instances-0.2.5.2-BXu5OpsjJssHybM5cub4Xk

haddock-interfaces:
    /usr/share/doc/haskell-binary-instances/html/binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-binary-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
